pub struct ParsedPublicKey { /* private fields */ }Expand description
A parsed public key for key agreement.
This represents a public key that has been successfully parsed and validated
from its encoded form. The key can be used with the agree function to
perform key agreement operations.
Implementations
Sourceimpl ParsedPublicKey
A parsed public key for key agreement.
impl ParsedPublicKey
A parsed public key for key agreement.