#[non_exhaustive]pub enum AlgorithmId {
Aes128,
Aes256,
Aes192,
DesForLegacyUseOnly,
DesEdeForLegacyUseOnly,
DesEde3ForLegacyUseOnly,
}Expand description
Cipher algorithm identifier.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Aes128
AES 128-bit
Aes256
AES 256-bit
Aes192
AES 192-bit
DesForLegacyUseOnly
Single DES is a legacy algorithm retained for interoperability only. Prefer an AES-based algorithm.
legacy-des only.Single DES (for legacy use only).
Single DES provides only 56 bits of effective security and has been considered insecure for decades.
DesEdeForLegacyUseOnly
2-key Triple DES is a legacy algorithm retained for interoperability only; NIST SP 800-131A Rev. 2 disallows its use for encryption. Prefer an AES-based algorithm.
legacy-des only.2TDEA (for legacy use only).
2-key Triple DES has been disallowed for encryption by NIST SP 800-131A Rev. 2 since 2015.
DesEde3ForLegacyUseOnly
3DES is a legacy algorithm retained for interoperability only; NIST SP 800-131A Rev. 2 disallows its use for encryption. Prefer an AES-based algorithm.
legacy-des only.3TDEA (for legacy use only).
3DES has been disallowed for encryption by NIST SP 800-131A Rev. 2 after 2023.